pub trait OpenBimImporter {
// Required method
fn import(
&self,
request: &OpenBimImportRequest,
) -> Result<InMemorySemanticSource, OpenBimError>;
}Expand description
Integration seam for IFC/STEP or other OpenBIM parser implementations.
Required Methods
Sourcefn import(
&self,
request: &OpenBimImportRequest,
) -> Result<InMemorySemanticSource, OpenBimError>
fn import( &self, request: &OpenBimImportRequest, ) -> Result<InMemorySemanticSource, OpenBimError>
Imports one source or returns an explicit integration failure.
Errors
Returns an error reported by the external importer, including
OpenBimError::IntegrationUnavailable.